@@ -28,12 +28,22 @@ How to use Panel widgets in 3 simple steps
 For more detail see the Reference Gallery guide.
 https://panel.holoviz.org/reference/chat/ChatInterface.html
 """
-from . import langchain  # noqa
+import importlib as _importlib
+
 from .feed import ChatFeed  # noqa
 from .icon import ChatReactionIcons  # noqa
 from .interface import ChatInterface  # noqa
 from .message import ChatMessage  # noqa
 
+
+def __getattr__(name):
+    """
+    Lazily import langchain module when accessed.
+    """
+    if name == 'langchain':
+        return _importlib.import_module('panel.chat.langchain')
+    raise AttributeError(f"module {__name__!r} has no attribute {name!r}")
+
 __all__ = (
     "ChatFeed",
     "ChatInterface",
