@@ -5,7 +5,7 @@ import {is_equal} from "@bokehjs/core/util/eq"
 import {ColumnDataSource} from "@bokehjs/models/sources/column_data_source";
 
 import {debounce} from  "debounce"
-import {deepCopy, isPlainObject, get, throttle} from "./util"
+import {deepCopy, isPlainObject, get, reshape, throttle} from "./util"
 
 import {HTMLBox, HTMLBoxView, set_size} from "./layout"
 
@@ -321,12 +321,7 @@ export class PlotlyPlotView extends HTMLBoxView {
     for (const column of cds.columns()) {
       let array = cds.get_array(column)[0];
       if (array.shape != null && array.shape.length > 1) {
-        const arrays = [];
-        const shape = array.shape;
-        for (let s = 0; s < shape[0]; s++) {
-          arrays.push(array.slice(s*shape[1], (s+1)*shape[1]));
-        }
-        array = arrays;
+	array = reshape(array, array.shape);
       }
       let prop_path = column.split(".");
       let prop = prop_path[prop_path.length - 1];
