@@ -1,6 +1,8 @@
 """
 React template
 """
+import json
+import math
 import pathlib
 
 import param
@@ -8,9 +10,8 @@ import param
 from ...config import config
 from ...depends import depends
 from ...io.resources import CSS_URLS
-from ...layout import Card, GridSpec
+from ...layout import GridSpec
 from ..base import BasicTemplate
-from ..theme import DarkTheme, DefaultTheme
 
 
 class ReactTemplate(BasicTemplate):
@@ -29,36 +30,25 @@ class ReactTemplate(BasicTemplate):
 
     row_height = param.Integer(default=150)
 
-    dimensions = param.Dict(default={'minW': 0, 'maxW': 'Infinity', 'minH': 0, 'maxH': 'Infinity'},
-                            doc="""A dictonary of minimum/maximum width/height in grid units.""")
+    dimensions = param.Dict(default={'minW': 0, 'maxW': float('inf'), 'minH': 0, 'maxH': float('inf')},
+                            doc="""A dictionary of minimum/maximum width/height in grid units.""")
 
     prevent_collision = param.Boolean(default=False, doc="Prevent collisions between items.")
 
     save_layout = param.Boolean(default=False, doc="Save layout to local storage.")
 
-    sidebar_width = param.Integer(350, doc="""
-        The width of the sidebar in pixels. Default is 350.""")
-
     _css = pathlib.Path(__file__).parent / 'react.css'
 
     _template = pathlib.Path(__file__).parent / 'react.html'
 
-    _modifiers = {
-        Card: {
-            'children': {'margin': (20, 20)},
-            'margin': (10, 5)
-        }
-    }
-
     _resources = {
         'js': {
-            'react': f"{config.npm_cdn}/react@18/umd/react.production.min.js",
-            'react-dom': f"{config.npm_cdn}/react-dom@18/umd/react-dom.production.min.js",
+            'react': f"{config.npm_cdn}/react@17/umd/react.production.min.js",
+            'react-dom': f"{config.npm_cdn}/react-dom@17/umd/react-dom.production.min.js",
             'babel': f"{config.npm_cdn}/babel-standalone@latest/babel.min.js",
             'react-grid': f"{config.npm_cdn}/react-grid-layout@1.3.4/dist/react-grid-layout.min.js"
         },
         'css': {
-            'bootstrap': CSS_URLS['bootstrap4'],
             'font-awesome': CSS_URLS['font-awesome']
         }
     }
@@ -80,9 +70,9 @@ class ReactTemplate(BasicTemplate):
             if y0 is None: y0 = 0
             if y1 is None: y1 = self.main.nrows
             elem = {'x': x0, 'y': y0, 'w': x1-x0, 'h': y1-y0, 'i': str(i+1)}
-            elem.update(self.dimensions)
+            elem.update({d: v for d, v in self.dimensions.items() if not math.isinf(v)})
             layouts.append(elem)
-        self._render_variables['layouts'] = {'lg': layouts, 'md': layouts}
+        self._render_variables['layouts'] = json.dumps({'lg': layouts, 'md': layouts})
 
     @depends('cols', 'breakpoints', 'row_height', 'compact', 'dimensions', 'prevent_collision',
              'save_layout', watch=True)
@@ -94,16 +84,3 @@ class ReactTemplate(BasicTemplate):
         self._render_variables['dimensions'] = self.dimensions
         self._render_variables['preventCollision'] = self.prevent_collision
         self._render_variables['saveLayout'] = self.save_layout
-
-class ReactDefaultTheme(DefaultTheme):
-
-    css = param.Filename(default=pathlib.Path(__file__).parent / 'default.css')
-
-    _template = ReactTemplate
-
-
-class ReactDarkTheme(DarkTheme):
-
-    css = param.Filename(default=pathlib.Path(__file__).parent / 'dark.css')
-
-    _template = ReactTemplate
