@@ -82,7 +82,7 @@ def test_resources_model_server(document):
         with set_curdoc(document):
             extension('tabulator')
             assert resources.js_files[:2] == [
-                'static/extensions/panel/bundled/datatabulator/tabulator-tables@5.5.0/dist/js/tabulator.js',
+                'static/extensions/panel/bundled/datatabulator/tabulator-tables@5.5.0/dist/js/tabulator.min.js',
                 'static/extensions/panel/bundled/datatabulator/luxon/build/global/luxon.min.js',
             ]
             assert resources.css_files == [
@@ -95,7 +95,7 @@ def test_resources_model_cdn(document):
         with set_curdoc(document):
             extension('tabulator')
             assert resources.js_files[:2] == [
-                f'{CDN_DIST}bundled/datatabulator/tabulator-tables@5.5.0/dist/js/tabulator.js',
+                f'{CDN_DIST}bundled/datatabulator/tabulator-tables@5.5.0/dist/js/tabulator.min.js',
                 f'{CDN_DIST}bundled/datatabulator/luxon/build/global/luxon.min.js',
             ]
             assert resources.css_files == [
@@ -108,7 +108,7 @@ def test_resources_model_inline(document):
         with set_curdoc(document):
             extension('tabulator')
             assert resources.js_raw[-2:] == [
-                (DIST_DIR / 'bundled/datatabulator/tabulator-tables@5.5.0/dist/js/tabulator.js').read_text(encoding='utf-8'),
+                (DIST_DIR / 'bundled/datatabulator/tabulator-tables@5.5.0/dist/js/tabulator.min.js').read_text(encoding='utf-8'),
                 (DIST_DIR / 'bundled/datatabulator/luxon/build/global/luxon.min.js').read_text(encoding='utf-8')
             ]
             assert resources.css_raw == [
