@@ -4,8 +4,9 @@ import numpy as np
 import pytest
 
 from panel.pane import panel
+from panel.tests.util import mpl_available
 from panel.widgets import (
-    CrossSelector, MultiChoice, MultiSelect, Select, ToggleGroup,
+    ColorMap, CrossSelector, MultiChoice, MultiSelect, Select, ToggleGroup,
 )
 
 
@@ -510,3 +511,62 @@ def test_cross_select_move_unselected_to_selected_not_definition_order():
 
     assert cross_select.value == ['A', 1, 'B', 3]
     assert cross_select._lists[True].options == ['A', '1', 'B', '3']
+
+def test_colormap_set_value_name(document, comm):
+    color_map = ColorMap(options={'A': ['#ff0', '#0ff'], 'B': ['#00f', '#f00']}, value=['#00f', '#f00'])
+
+    model = color_map.get_root(document, comm=comm)
+
+    assert model.value == 'B'
+    assert color_map.value_name == 'B'
+
+    color_map.value = ['#ff0', '#0ff']
+
+    assert model.value == 'A'
+    assert color_map.value_name == 'A'
+
+def test_colormap_set_value(document, comm):
+    color_map = ColorMap(options={'A': ['#ff0', '#0ff'], 'B': ['#00f', '#f00']}, value_name='B')
+
+    model = color_map.get_root(document, comm=comm)
+
+    assert model.value == 'B'
+    assert color_map.value == ['#00f', '#f00']
+
+    color_map.value_name = 'A'
+
+    assert model.value == 'A'
+    assert color_map.value == ['#ff0', '#0ff']
+
+@mpl_available
+def test_colormap_mpl_cmap(document, comm):
+    from matplotlib.cm import Set1, tab10
+    color_map = ColorMap(options={'tab10': tab10, 'Set1': Set1}, value_name='Set1')
+
+    model = color_map.get_root(document, comm=comm)
+
+    assert model.items == [
+        ('tab10', [
+            'rgba(31, 119, 180, 1)',
+            'rgba(255, 127, 14, 1)',
+            'rgba(44, 160, 44, 1)',
+            'rgba(214, 39, 40, 1)',
+            'rgba(148, 103, 189, 1)',
+            'rgba(140, 86, 75, 1)',
+            'rgba(227, 119, 194, 1)',
+            'rgba(127, 127, 127, 1)',
+            'rgba(188, 189, 34, 1)',
+            'rgba(23, 190, 207, 1)'
+        ]),
+        ('Set1', [
+            'rgba(228, 26, 28, 1)',
+            'rgba(55, 126, 184, 1)',
+            'rgba(77, 175, 74, 1)',
+            'rgba(152, 78, 163, 1)',
+            'rgba(255, 127, 0, 1)',
+            'rgba(255, 255, 51, 1)',
+            'rgba(166, 86, 40, 1)',
+            'rgba(247, 129, 191, 1)',
+            'rgba(153, 153, 153, 1)'
+        ])
+    ]
